Name:         ksh
Summary:      The Original ATT Korn Shell
URL:          http://www.kornshell.com/
License:      EPL-2.0
Epoch:        3
Version:      1.0.10
Release:      %mkrel 2
Group:        Shells
Source0:      https://github.com/ksh93/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:      kshcomp.conf
Source2:      kshrc.rhs
Source3:      dotkshrc

Conflicts:    pdksh
Requires: coreutils, diffutils
BuildRequires: gcc
BuildRequires: bison

# regression test suite requirements
BuildRequires: locales-ja
BuildRequires: ncurses
BuildRequires: procps
BuildRequires: tzdata
BuildRequires: util-linux

Requires(post): grep, coreutils, systemd
Requires(postun): sed

Provides: /bin/ksh
Provides: /bin/rksh

%description
KSH-93 is the most recent version of the KornShell by David Korn of
AT&T Bell Laboratories.
KornShell is a shell programming language, which is upward compatible
with "sh" (the Bourne Shell).

%prep
%autosetup -p1

# /dev/fd test does not work because of mock
sed -i 's|ls /dev/fd|ls /proc/self/fd|' src/cmd/ksh93/features/options

%build
XTRAFLAGS=""
for f in -Wno-unknown-pragmas -Wno-missing-braces -Wno-unused-result -Wno-return-type -Wno-int-to-pointer-cast -Wno-parentheses -Wno-unused -Wno-unused-but-set-variable -Wno-cpp -Wno-maybe-uninitialized -Wno-lto-type-mismatch
do
  $CC $f -E - </dev/null >/dev/null 2>&1 && XTRAFLAGS="$XTRAFLAGS $f"
done
export CCFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing $XTRAFLAGS"
export LDFLAGS="$RPM_LD_FLAGS"
bin/package make

%install
mkdir -p %{buildroot}{%{_bindir},%{_mandir}/man1}
install -p -m 755 arch/*/bin/ksh %{buildroot}%{_bindir}/ksh93
install -p -m 755 arch/*/bin/shcomp %{buildroot}%{_bindir}/shcomp
install -p -m 644 arch/*/man/man1/sh.1 %{buildroot}%{_mandir}/man1/ksh93.1
install -p -D -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/skel/.kshrc
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/kshrc
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/binfmt.d/kshcomp.conf

touch %{buildroot}%{_bindir}/ksh
touch %{buildroot}%{_mandir}/man1/ksh.1.xz

touch %{buildroot}%{_bindir}/rksh
touch %{buildroot}%{_mandir}/man1/rksh.1.xz

%check
# script is needed for pty tests in mock
script -q -e -c "bin/package test"

%post
for s in /bin/ksh /bin/rksh /usr/bin/ksh /usr/bin/rksh
do
  if [ ! -f /etc/shells ]; then
        echo "$s" > /etc/shells
  else
        if ! grep -q '^'"$s"'$' /etc/shells ; then
                echo "$s" >> /etc/shells
        fi
  fi
done

%{_sbindir}/alternatives --install %{_bindir}/ksh ksh \
                %{_bindir}/ksh93 50 \
        --slave %{_bindir}/rksh rksh \
                %{_bindir}/ksh93 \
        --slave %{_mandir}/man1/rksh.1.xz rksh-man \
                %{_mandir}/man1/ksh93.1.xz \
        --slave %{_mandir}/man1/ksh.1.xz ksh-man \
                %{_mandir}/man1/ksh93.1.xz

#if not symlink we are updating ksh where there was no alternatives before
#so replace with symlink and set alternatives
if [ ! -L %{_bindir}/ksh ]; then
        %{_sbindir}/alternatives --auto ksh
        ln -sf /etc/alternatives/ksh %{_bindir}/ksh
        ln -sf /etc/alternatives/ksh-man %{_mandir}/man1/ksh.1.xz
fi

/bin/systemctl try-restart systemd-binfmt.service >/dev/null 2>&1 || :

%postun
for s in /bin/ksh /bin/rksh /usr/bin/ksh /usr/bin/rksh
do
  if [ ! -f $s ]; then
        sed -i '\|^'"$s"'$|d' /etc/shells
  fi
done

%preun
if [ $1 = 0 ]; then
        %{_sbindir}/alternatives --remove ksh %{_bindir}/ksh93
fi

%verifyscript
echo -n "Looking for ksh in /etc/shells... "
if ! grep '^/bin/ksh$' /etc/shells > /dev/null; then
    echo "missing"
    echo "ksh missing from /etc/shells" >&2
else
    echo "found"
fi

%files 
%doc src/cmd/ksh93/{COMPATIBILITY,RELEASE,TYPES,README}
%doc README.md NEWS
%license LICENSE.md
%{_bindir}/ksh93
%ghost %{_bindir}/ksh
%ghost %{_bindir}/rksh
%{_bindir}/shcomp
%{_mandir}/man1/ksh93.1*
%ghost %{_mandir}/man1/ksh.1*
%ghost %{_mandir}/man1/rksh.1*
%config(noreplace) %{_sysconfdir}/skel/.kshrc
%config(noreplace) %{_sysconfdir}/kshrc
%config(noreplace) %{_sysconfdir}/binfmt.d/kshcomp.conf


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 3:1.0.10-2.mga10
+ Revision: 2230133
- Mageia 10 Mass Rebuild

* Thu Nov 21 2024 ns80 <ns80> 3:1.0.10-1.mga10
+ Revision: 2118108
- man pages are compressed with xz
- new version 1.0.10, synched with Fedora
+ kekepower <kekepower>
- ksh2020 is no longer maintained or supported

* Sat Feb 15 2020 umeabot <umeabot> 1:2020.0.0.338.git8d91e8a-0.2.mga8
+ Revision: 1528022
- Mageia 8 Mass Rebuild

* Wed Aug 07 2019 kekepower <kekepower> 1:2020.0.0.338.git8d91e8a-0.1.mga8
+ Revision: 1427902
- Update to release 338.git8d91e8a

* Thu Jul 18 2019 kekepower <kekepower> 1:2020.0.0.281.gite22e079-0.1.mga8
+ Revision: 1422641
- Update to release 281.gite22e079

* Thu Jul 04 2019 kekepower <kekepower> 1:2020.0.0.213.git21343a7-0.1.mga8
+ Revision: 1418171
- Update to release commit 213

* Wed May 08 2019 kekepower <kekepower> 1:2020.0.0.81.git8052490-0.1.mga7
+ Revision: 1396657
- Update to build 81, 20190508

* Tue Apr 23 2019 kekepower <kekepower> 1:2020.0.0.22.git0a19ba5-0.2.mga7
+ Revision: 1394971
- Update to version 2020.0.0.22.git0a19ba5

* Wed Apr 17 2019 umeabot <umeabot> 20190327_gitf5f5105-0.2.mga7
+ Revision: 1392703
- Rebuild with meson 0.50.1

* Wed Mar 27 2019 kekepower <kekepower> 20190327_gitf5f5105-0.1.mga7
+ Revision: 1380601
- Update to release 20190327_gitf5f5105

* Mon Mar 11 2019 kekepower <kekepower> 20190311_gitb6e8ac01-0.1.mga7
+ Revision: 1373954
- Update to release 20190311_gitb6e8ac01

* Mon Feb 11 2019 kekepower <kekepower> 20190211_git00de374d-0.1.mga7
+ Revision: 1365330
- Update to release 20190211_git00de374d

* Sat Jan 05 2019 kekepower <kekepower> 20190105_gitb8d8824-0.1.mga7
+ Revision: 1349922
- Update to release 20190105_gitb8d8824

* Tue Dec 18 2018 kekepower <kekepower> 20181218_git4b8c87f-0.1.mga7
+ Revision: 1342490
- Update to release 20181218_git4b8c87f

* Sat Dec 01 2018 kekepower <kekepower> 20181201_git6c646453-0.1.mga7
+ Revision: 1336971
- Update to release 20181201_git6c646453

* Fri Nov 23 2018 kekepower <kekepower> 20181121_git3e524bde-0.1.mga7
+ Revision: 1333513
- Update to reløease 20181121_git3e524bde

* Thu Nov 01 2018 kekepower <kekepower> 20181101_gitdc6761a9-0.1.mga7
+ Revision: 1327113
- Update to release 20181101_gitdc6761a9

* Mon Oct 15 2018 kekepower <kekepower> 20181014_git0367856c-0.1.mga7
+ Revision: 1320425
- Update to release 20181014-0367856c

* Mon Oct 01 2018 kekepower <kekepower> 20181001_git61ebba70-0.1.mga7
+ Revision: 1314340
- Update to release 20181001-git61ebba70

* Thu Sep 20 2018 kekepower <kekepower> 20180920_git8d69ea8f-0.1.mga7
+ Revision: 1282802
- Update to release 20180920_git8d69ea8f

* Thu Sep 06 2018 kekepower <kekepower> 20180906_git681aa332-0.1.mga7
+ Revision: 1257608
- Update to release 20180906_git681aa332

* Tue Aug 21 2018 kekepower <kekepower> 20180821_git05c81a4e-0.1.mga7
+ Revision: 1253333
- Update to release 20180821-05c81a4e

* Tue Aug 07 2018 kekepower <kekepower> 20180807_git3d8a9fe4-0.1.mga7
+ Revision: 1248805
- Update to release 20180807-3d8a9fe4

* Fri Jun 15 2018 kekepower <kekepower> 20180615_gitfc439a31-0.1.mga7
+ Revision: 1237004
- Update to latest git master, 20180615

* Sun Jun 03 2018 kekepower <kekepower> 20180603_git235ea6b4-0.1.mga7
+ Revision: 1233967
- Update to release 20180603, git master 235ea6b4

* Thu May 31 2018 kekepower <kekepower> 20180531_git9c99e73a-0.2.mga7
+ Revision: 1233227
- Update 559.patch to test build failuer on ARM

* Thu May 31 2018 kekepower <kekepower> 20180531_git9c99e73a-0.1.mga7
+ Revision: 1233193
- Add upstream patch for a possible fix for build failure on ARM

* Wed May 30 2018 kekepower <kekepower> 20180530_git11398511e-0.2.mga7
+ Revision: 1233173
- Test build for ARM (https://github.com/att/ast/issues/558)

* Tue May 29 2018 kekepower <kekepower> 20180529_gitebe3b505-0.1.mga7
+ Revision: 1233009
- Update to release 20180529_gitebe3b505

* Mon May 21 2018 kekepower <kekepower> 20180520_git46885145-0.1.mga7
+ Revision: 1230870
- Update to release 20180520

* Fri May 04 2018 kekepower <kekepower> 20180503_git9b96d4a4-0.1.mga7
+ Revision: 1226222
- Sync the KSH package with Fedora
+ ahmad <ahmad>
- add BR bison
+ ennael <ennael>
- add missing buildrequire
- clean spec file
- imported package ksh


* Wed Jul 23 2008 Oden Eriksson <oeriksson@mandriva.com> 93t-1mdv2009.0
+ Revision: 242358
- 93t (2008-06-24)
- package it the PLD way
- added P0 to make it build
- it requires -fPIC, make it so...
- nuke rpath with chrpath

  + Thierry Vignaud <tvignaud@mandriva.com>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request
    - use %%mkrel

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Fri Apr 15 2005 Claudio Matsuoka <claudio@mandriva.com> 93q-1mdk
- package creation

